#ifndef NT2_INCLUDE_FUNCTIONS_FACTORIAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_FACTORIAL_HPP_INCLUDED

#include <nt2/combinatorial/include/functions/factorial.hpp>

#endif
